cmd

package
v0.0.0-...-b010486 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 20, 2018 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

const DeleteUsrMsg = "User \"%s\" deleted\n"
const NewUsrMsgNonScoped = "User \"%s\" created with cluster-wide rights in namespace \"%s\"\n"
const NewUsrMsgScoped = "User \"%s\" created with scoped rights in namespace \"%s\"\n"
const UserLabelSelector = "type=user"

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

type KubeConfig

type KubeConfig struct {
	Kind           string                    `yaml:"kind"`
	ApiVersion     string                    `yaml:"apiVersion"`
	CurrentContext string                    `yaml:"current-context"`
	Clusters       []*KubectlClusterWithName `yaml:"clusters"`
	Contexts       []*KubectlContextWithName `yaml:"contexts"`
	Users          []*KubectlUserWithName    `yaml:"users"`
}

type KubectlCluster

type KubectlCluster struct {
	Server                   string `yaml:"server,omitempty"`
	CertificateAuthorityData string `yaml:"certificate-authority-data,omitempty"`
}

type KubectlClusterWithName

type KubectlClusterWithName struct {
	Name    string         `yaml:"name"`
	Cluster KubectlCluster `yaml:"cluster"`
}

type KubectlContext

type KubectlContext struct {
	Cluster   string `yaml:"cluster"`
	User      string `yaml:"user"`
	Namespace string `yaml:"namespace"`
}

type KubectlContextWithName

type KubectlContextWithName struct {
	Name    string         `yaml:"name"`
	Context KubectlContext `yaml:"context"`
}

type KubectlUser

type KubectlUser struct {
	Token string `yaml:"token,omitempty"`
}

type KubectlUserWithName

type KubectlUserWithName struct {
	Name string      `yaml:"name"`
	User KubectlUser `yaml:"user"`
}

type User

type User struct {
	Name      string `yaml:"name"`
	Scope     string `yaml:"scope"`
	Namespace string `yaml:"namespace"`
}

Represent a new user

type UserList

type UserList struct {
	Items []User `yaml:"list"`
}

Directories

Path Synopsis

Jump to